@@ -18,7 +18,7 @@ class AspectFrameExample:
                                        0.5, # center x
                                        0.5, # center y
                                        2, # xsize/ysize = 2
-                                       gtk.FALSE) # ignore child's aspect
+                                       False) # ignore child's aspect
         window.add(aspect_frame)
         aspect_frame.show()
 
