@@ -11,7 +11,7 @@ import gtk
 
 def xpm_label_box(parent, xpm_filename, label_text):
     # Create box for xpm and label
-    box1 = gtk.HBox(gtk.FALSE, 0)
+    box1 = gtk.HBox(False, 0)
     box1.set_border_width(2)
 
     # Now on to the image stuff
@@ -22,8 +22,8 @@ def xpm_label_box(parent, xpm_filename, label_text):
     label = gtk.Label(label_text)
 
     # Pack the pixmap and label into the box
-    box1.pack_start(image, gtk.FALSE, gtk.FALSE, 3)
-    box1.pack_start(label, gtk.FALSE, gtk.FALSE, 3)
+    box1.pack_start(image, False, False, 3)
+    box1.pack_start(label, False, False, 3)
 
     image.show()
     label.show()
