@@ -15,7 +15,7 @@ class CheckButton:
     # This callback quits the program
     def delete_event(self, widget, event, data=None):
         gtk.main_quit()
-        return gtk.FALSE
+        return False
 
     def __init__(self):
         # Create a new window
@@ -32,7 +32,7 @@ class CheckButton:
         self.window.set_border_width(20)
 
         # Create a vertical box
-        vbox = gtk.VBox(gtk.TRUE, 2)
+        vbox = gtk.VBox(True, 2)
 
         # Put the vbox in the main window
         self.window.add(vbox)
@@ -46,7 +46,7 @@ class CheckButton:
 
 
         # Insert button 1
-        vbox.pack_start(button, gtk.TRUE, gtk.TRUE, 2)
+        vbox.pack_start(button, True, True, 2)
 
         button.show()
 
@@ -58,7 +58,7 @@ class CheckButton:
         # with a pointer to "button 2" as its argument
         button.connect("toggled", self.callback, "check button 2")
         # Insert button 2
-        vbox.pack_start(button, gtk.TRUE, gtk.TRUE, 2)
+        vbox.pack_start(button, True, True, 2)
 
         button.show()
 
@@ -70,7 +70,7 @@ class CheckButton:
         button.connect("clicked", lambda wid: gtk.main_quit())
 
         # Insert the quit button
-        vbox.pack_start(button, gtk.TRUE, gtk.TRUE, 2)
+        vbox.pack_start(button, True, True, 2)
 
         button.show()
         vbox.show()
