@@ -80,7 +80,7 @@ class DrawingAreaExample:
         self.draw_pixmap(310, 100)
         self.draw_polygon(10, 200)
         self.draw_rgb_image(110, 200)
-        return gtk.TRUE
+        return True
 
     def draw_point(self, x, y):
         self.area.window.draw_point(self.gc, x+30, y+30)
@@ -119,22 +119,22 @@ class DrawingAreaExample:
         return
 
     def draw_rectangles(self, x, y):
-        self.area.window.draw_rectangle(self.gc, gtk.FALSE, x, y, 80, 70)
-        self.area.window.draw_rectangle(self.gc, gtk.TRUE, x+10, y+10, 20, 20)
-        self.area.window.draw_rectangle(self.gc, gtk.TRUE, x+50, y+10, 20, 20)
-        self.area.window.draw_rectangle(self.gc, gtk.TRUE, x+20, y+50, 40, 10)
+        self.area.window.draw_rectangle(self.gc, False, x, y, 80, 70)
+        self.area.window.draw_rectangle(self.gc, True, x+10, y+10, 20, 20)
+        self.area.window.draw_rectangle(self.gc, True, x+50, y+10, 20, 20)
+        self.area.window.draw_rectangle(self.gc, True, x+20, y+50, 40, 10)
         self.pangolayout.set_text("Rectangles")
         self.area.window.draw_layout(self.gc, x+5, y+80, self.pangolayout)
         return
 
     def draw_arcs(self, x, y):
-        self.area.window.draw_arc(self.gc, gtk.FALSE, x+10, y, 70, 70,
+        self.area.window.draw_arc(self.gc, False, x+10, y, 70, 70,
                                   0, 360*64)
-        self.area.window.draw_arc(self.gc, gtk.TRUE, x+30, y+20, 10, 10,
+        self.area.window.draw_arc(self.gc, True, x+30, y+20, 10, 10,
                                   0, 360*64)
-        self.area.window.draw_arc(self.gc, gtk.TRUE, x+50, y+20, 10, 10,
+        self.area.window.draw_arc(self.gc, True, x+50, y+20, 10, 10,
                                   0, 360*64)
-        self.area.window.draw_arc(self.gc, gtk.TRUE, x+30, y+10, 30, 50,
+        self.area.window.draw_arc(self.gc, True, x+30, y+10, 30, 50,
                                   210*64, 120*64)
         self.pangolayout.set_text("Arcs")
         self.area.window.draw_layout(self.gc, x+5, y+80, self.pangolayout)
@@ -153,7 +153,7 @@ class DrawingAreaExample:
     def draw_polygon(self, x, y):
         points = [(x+10,y+60), (x+10,y+20), (x+40,y+70),
                   (x+30,y+30), (x+50,y+40)]
-        self.area.window.draw_polygon(self.gc, gtk.TRUE, points)
+        self.area.window.draw_polygon(self.gc, True, points)
         self.pangolayout.set_text("Polygon")
         self.area.window.draw_layout(self.gc, x+5, y+80, self.pangolayout)
         return
