@@ -22,10 +22,10 @@ def entry_point(widget):
     print "You've changed my text to '%s'" % widget.get_text()
 
 entry.connect("changed", entry_point)
-plug.connect("destroy", gtk.mainquit)
+plug.connect("destroy", lambda w: gtk.main_quit())
 
 plug.add(entry)
 plug.show_all()
 
 
-gtk.mainloop()
+gtk.main()
