@@ -4,7 +4,7 @@
 
 import pygtk
 pygtk.require('2.0')
-import gtk
+import gtk, gobject
 
 # Update the value of the progress bar so that we get
 # some movement
@@ -22,7 +22,7 @@ def progress_timeout(pbobj):
 
     # As this is a timeout function, return TRUE so that it
     # continues to get called
-    return gtk.TRUE
+    return True
 
 class ProgressBar:
     # Callback that toggles the text display within the progress
@@ -50,26 +50,26 @@ class ProgressBar:
 
     # Clean up allocated memory and remove the timer
     def destroy_progress(self, widget, data=None):
-        gtk.timeout_remove(self.timer)
+        gobject.source_remove(self.timer)
         self.timer = 0
         gtk.main_quit()
 
     def __init__(self):
         self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
-        self.window.set_resizable(gtk.TRUE)
+        self.window.set_resizable(True)
 
         self.window.connect("destroy", self.destroy_progress)
         self.window.set_title("ProgressBar")
         self.window.set_border_width(0)
 
-        vbox = gtk.VBox(gtk.FALSE, 5)
+        vbox = gtk.VBox(False, 5)
         vbox.set_border_width(10)
         self.window.add(vbox)
         vbox.show()
   
         # Create a centering alignment object
         align = gtk.Alignment(0.5, 0.5, 0, 0)
-        vbox.pack_start(align, gtk.FALSE, gtk.FALSE, 5)
+        vbox.pack_start(align, False, False, 5)
         align.show()
 
         # Create the ProgressBar
@@ -79,15 +79,15 @@ class ProgressBar:
         self.pbar.show()
 
         # Add a timer callback to update the value of the progress bar
-        self.timer = gtk.timeout_add (100, progress_timeout, self)
+        self.timer = gobject.timeout_add (100, progress_timeout, self)
 
         separator = gtk.HSeparator()
-        vbox.pack_start(separator, gtk.FALSE, gtk.FALSE, 0)
+        vbox.pack_start(separator, False, False, 0)
         separator.show()
 
         # rows, columns, homogeneous
-        table = gtk.Table(2, 2, gtk.FALSE)
-        vbox.pack_start(table, gtk.FALSE, gtk.TRUE, 0)
+        table = gtk.Table(2, 2, False)
+        vbox.pack_start(table, False, True, 0)
         table.show()
 
         # Add a check button to select displaying of the trough text
@@ -117,7 +117,7 @@ class ProgressBar:
         # Add a button to exit the program
         button = gtk.Button("close")
         button.connect("clicked", self.destroy_progress)
-        vbox.pack_start(button, gtk.FALSE, gtk.FALSE, 0)
+        vbox.pack_start(button, False, False, 0)
 
         # This makes it so the button is the default.
         button.set_flags(gtk.CAN_DEFAULT)
