@@ -12,7 +12,7 @@ import socket, select
 from code import InteractiveInterpreter, InteractiveConsole
 
 import gtk
-from gtk import TRUE, FALSE
+import gobject
 
 # For compatibility, instead of using GDK.INPUT_READ or
 # gtk.gdk.INPUT_READ depending on the PyGtk version
@@ -23,7 +23,7 @@ class Mainloop(InteractiveInterpreter):
         InteractiveInterpreter.__init__(self)
         self._rfd = os.fdopen(read_fd, 'r')
         self._sock = sock
-        gtk.input_add(read_fd, GDK_INPUT_READ, self.input_func)
+        gobject.io_add_watch(read_fd, GDK_INPUT_READ, self.input_func)
 
     def read_message(self):
         length = ord(self._rfd.read(1))
@@ -33,7 +33,7 @@ class Mainloop(InteractiveInterpreter):
         data = self.read_message()
         more = self.runsource(data)
         self._sock.send(chr(more))
-        return TRUE
+        return True
 
     def run(self):
         gtk.main()
