@@ -36,28 +36,28 @@ def configure_event(widget, event):
     x, y, width, height = widget.get_allocation()
     pixmap = gtk.gdk.Pixmap(widget.window, width, height)
     pixmap.draw_rectangle(widget.get_style().white_gc,
-                          gtk.TRUE, 0, 0, width, height)
+                          True, 0, 0, width, height)
 
-    return gtk.TRUE
+    return True
 
 # Redraw the screen from the backing pixmap
 def expose_event(widget, event):
     x , y, width, height = event.area
     widget.window.draw_drawable(widget.get_style().fg_gc[gtk.STATE_NORMAL],
                                 pixmap, x, y, x, y, width, height)
-    return gtk.FALSE
+    return False
 
 # Draw a rectangle on the screen
 def draw_brush(widget, x, y):
     rect = (int(x-5), int(y-5), 10, 10)
-    pixmap.draw_rectangle(widget.get_style().black_gc, gtk.TRUE,
+    pixmap.draw_rectangle(widget.get_style().black_gc, True,
                           rect[0], rect[1], rect[2], rect[3])
     widget.queue_draw_area(rect[0], rect[1], rect[2], rect[3])
 
 def button_press_event(widget, event):
     if event.button == 1 and pixmap != None:
         draw_brush(widget, event.x, event.y)
-    return gtk.TRUE
+    return True
 
 def motion_notify_event(widget, event):
     if event.is_hint:
@@ -70,13 +70,13 @@ def motion_notify_event(widget, event):
     if state & gtk.gdk.BUTTON1_MASK and pixmap != None:
         draw_brush(widget, x, y)
   
-    return gtk.TRUE
+    return True
 
 def main():
     window = gtk.Window(gtk.WINDOW_TOPLEVEL)
     window.set_name ("Test Input")
 
-    vbox = gtk.VBox(gtk.FALSE, 0)
+    vbox = gtk.VBox(False, 0)
     window.add(vbox)
     vbox.show()
 
@@ -85,7 +85,7 @@ def main():
     # Create the drawing area
     drawing_area = gtk.DrawingArea()
     drawing_area.set_size_request(200, 200)
-    vbox.pack_start(drawing_area, gtk.TRUE, gtk.TRUE, 0)
+    vbox.pack_start(drawing_area, True, True, 0)
 
     drawing_area.show()
 
@@ -105,7 +105,7 @@ def main():
 
     # .. And a quit button
     button = gtk.Button("Quit")
-    vbox.pack_start(button, gtk.FALSE, gtk.FALSE, 0)
+    vbox.pack_start(button, False, False, 0)
 
     button.connect_object("clicked", lambda w: w.destroy(), window)
     button.show()
