@@ -14,7 +14,7 @@ socket.show()
 window.add(socket)
 
 print "Socket ID=", socket.get_id()
-window.connect("destroy", gtk.mainquit)
+window.connect("destroy", lambda w: gtk.main_quit())
 
 def plugged_event(widget):
     print "I (", widget, ") have just had a plug inserted!"
@@ -24,4 +24,4 @@ socket.connect("plug-added", plugged_event)
 if len(sys.argv) == 2:
     socket.add_id(long(sys.argv[1]))
 
-gtk.mainloop()
+gtk.main()
