@@ -76,13 +76,13 @@ def hue_to_color(hue):
 class FileSel(gtk.FileSelection):
     def __init__(self):
         gtk.FileSelection.__init__(self)
-        self.result = gtk.FALSE
+        self.result = False
 
     def ok_cb(self, button):
         self.hide()
         if self.ok_func(self.get_filename()):
             self.destroy()
-            self.result = gtk.TRUE
+            self.result = True
         else:
             self.show()
 
@@ -94,7 +94,7 @@ class FileSel(gtk.FileSelection):
         self.ok_button.connect("clicked", self.ok_cb)
         self.cancel_button.connect("clicked", lambda x: self.destroy())
         self.connect("destroy", lambda x: gtk.main_quit())
-        self.set_modal(gtk.TRUE)
+        self.set_modal(True)
         self.show()
         gtk.main()
         return self.result
@@ -117,12 +117,12 @@ class Buffer(gtk.TextBuffer):
             tag = self.create_tag()
             self.color_tags.append(tag)
   
-        #self.invisible_tag = self.create_tag(None, invisible=gtk.TRUE)
-        self.not_editable_tag = self.create_tag(editable=gtk.FALSE,
+        #self.invisible_tag = self.create_tag(None, invisible=True)
+        self.not_editable_tag = self.create_tag(editable=False,
                                                 foreground="purple")
         self.found_text_tag = self.create_tag(foreground="red")
 
-        tabs = pango.TabArray(4, gtk.TRUE)
+        tabs = pango.TabArray(4, True)
         tabs.set_tab(0, pango.TAB_LEFT, 10)
         tabs.set_tab(1, pango.TAB_LEFT, 30)
         tabs.set_tab(2, pango.TAB_LEFT, 60)
@@ -187,10 +187,10 @@ class Buffer(gtk.TextBuffer):
         dialog.show()
 
     def search_forward(self, str, view):
-        self.search(str, view, gtk.TRUE)
+        self.search(str, view, True)
 
     def search_backward(self, str, view):
-        self.search(str, view, gtk.FALSE)
+        self.search(str, view, False)
 
     def ref(self):
         self.refcount += 1
@@ -198,13 +198,13 @@ class Buffer(gtk.TextBuffer):
     def unref(self):
         self.refcount -= 1
         if self.refcount == 0:
-            self.set_colors(gtk.FALSE)
+            self.set_colors(False)
             TestText.buffers.remove(self)
             del self
 
     def color_cycle_timeout(self):
         self.cycle_colors()
-        return gtk.TRUE
+        return True
 
     def set_colors(self, enabled):
         hue = 0.0
@@ -222,7 +222,7 @@ class Buffer(gtk.TextBuffer):
                               hue_to_color(hue))
                 tag.set_property("foreground_gdk", color)
             else:
-                tag.set_property("foreground_set", gtk.FALSE)
+                tag.set_property("foreground_set", False)
             hue += 1.0 / Buffer.N_COLORS
       
     def cycle_colors(self):
@@ -258,7 +258,7 @@ class Buffer(gtk.TextBuffer):
               event.type == gtk.gdk.KEY_RELEASE):
             print "Key event at char %d tag `%s'\n" % (char_index, tag_name)
 
-        return gtk.FALSE
+        return False
 
     def init_tags(self):
         colormap = TestText.colormap
@@ -282,7 +282,7 @@ class Buffer(gtk.TextBuffer):
         tag.connect("event", self.tag_event_handler)
 
         tag = self.create_tag("strikethrough",
-                                strikethrough=gtk.TRUE)
+                                strikethrough=True)
         tag.connect("event", self.tag_event_handler)
 
         tag = self.create_tag("underline",
@@ -324,7 +324,7 @@ class Buffer(gtk.TextBuffer):
                           "(Hello World!)\nfoo foo Hello this is some text we are using to text word wrap. It has punctuation! gee; blah - hmm, great.\nnew line with a significant quantity of text on it. This line really does contain some text. More text! More text! More text!\n"
                           "German (Deutsch Süd) Grüß Gott Greek (Ελληνικά) Γειά σας Hebrew(שלום) Hebrew punctuation(\xd6\xbfש\xd6\xbb\xd6\xbc\xd6\xbb\xd6\xbfל\xd6\xbcו\xd6\xbc\xd6\xbb\xd6\xbb\xd6\xbfם\xd6\xbc\xd6\xbb\xd6\xbf) Japanese (日本語) Thai (สวัสดีครับ) Thai wrong spelling (คำต่อไปนื่สะกดผิด พัั้ัั่งโกะ)\n")
 
-            temp_mark = self.create_mark("tmp_mark", iter, gtk.TRUE);
+            temp_mark = self.create_mark("tmp_mark", iter, True);
 
             iter = self.get_iter_at_line_offset(0, 6)
             iter2 = self.get_iter_at_line_offset(0, 13)
@@ -372,7 +372,7 @@ class Buffer(gtk.TextBuffer):
         # Move cursor to start
         iter = self.get_iter_at_offset(0)
         self.place_cursor(iter)
-        self.set_modified(gtk.FALSE)
+        self.set_modified(False)
 
     def fill_file_buffer(self, filename):
         try:
@@ -385,20 +385,20 @@ class Buffer(gtk.TextBuffer):
                                        gtk.BUTTONS_OK, err);
             result = dialog.run()
             dialog.destroy()
-            return gtk.FALSE
+            return False
   
         iter = self.get_iter_at_offset(0)
         buf = f.read()
         f.close()
         self.set_text(buf)
-        self.set_modified(gtk.FALSE)
-        return gtk.TRUE
+        self.set_modified(False)
+        return True
 
     def save_buffer(self):
-        result = gtk.FALSE
-        have_backup = gtk.FALSE
+        result = False
+        have_backup = False
         if not self.filename:
-            return gtk.FALSE
+            return False
 
         bak_filename = self.filename + "~"
         try:
@@ -414,17 +414,17 @@ class Buffer(gtk.TextBuffer):
                                            gtk.BUTTONS_OK, err);
                 dialog.run()
                 dialog.destroy()
-                return gtk.FALSE
+                return False
 
-        have_backup = gtk.TRUE
+        have_backup = True
         start, end = self.get_bounds()
-        chars = self.get_slice(start, end, gtk.FALSE)
+        chars = self.get_slice(start, end, False)
         try:
             file = open(self.filename, "w")
             file.write(chars)
             file.close()
-            result = gtk.TRUE
-            self.set_modified(gtk.FALSE)
+            result = True
+            self.set_modified(False)
         except IOError, (errnum, errmsg):
             err = "Error writing to '%s': %s" % (self.filename, errmsg)
             view = TestText.active_window_stack.get()
@@ -462,16 +462,16 @@ class Buffer(gtk.TextBuffer):
                 result = dialog.run()
                 dialog.destroy()
                 if result != gtk.RESPONSE_YES:
-                    return gtk.FALSE
+                    return False
   
         self.filename = filename
 
         if self.save_buffer():
             self.filename_set()
-            return gtk.TRUE
+            return True
         else:
             self.filename = old_filename
-            return gtk.FALSE
+            return False
 
     def save_as_buffer(self):
         return FileSel().run(self, "Save File", None, self.save_as_ok_func)
@@ -492,11 +492,11 @@ class Buffer(gtk.TextBuffer):
                     return self.save_buffer()
                 return self.save_as_buffer()
             elif result == gtk.RESPONSE_NO:
-                return gtk.TRUE
+                return True
             else:
-                return gtk.FALSE
+                return False
         else:
-            return gtk.TRUE
+            return True
 
 class View(gtk.Window):
     def __init__(self, buffer=None):
@@ -517,29 +517,29 @@ class View(gtk.Window):
             ( "/Settings/Wrap _Words", None, self.do_wrap_changed, gtk.WRAP_WORD, "/Settings/Wrap Off" ),
             ( "/Settings/Wrap _Chars", None, self.do_wrap_changed, gtk.WRAP_CHAR, "/Settings/Wrap Off" ),
             ( "/Settings/sep1", None, None, 0, "<Separator>" ),
-            ( "/Settings/Editable", None, self.do_editable_changed, gtk.TRUE, "<RadioItem>" ),
-            ( "/Settings/Not editable", None, self.do_editable_changed, gtk.FALSE, "/Settings/Editable" ),
+            ( "/Settings/Editable", None, self.do_editable_changed, True, "<RadioItem>" ),
+            ( "/Settings/Not editable", None, self.do_editable_changed, False, "/Settings/Editable" ),
             ( "/Settings/sep1", None, None, 0, "<Separator>" ),
-            ( "/Settings/Cursor visible", None, self.do_cursor_visible_changed, gtk.TRUE, "<RadioItem>" ),
-            ( "/Settings/Cursor not visible", None, self.do_cursor_visible_changed, gtk.FALSE, "/Settings/Cursor visible" ),
+            ( "/Settings/Cursor visible", None, self.do_cursor_visible_changed, True, "<RadioItem>" ),
+            ( "/Settings/Cursor not visible", None, self.do_cursor_visible_changed, False, "/Settings/Cursor visible" ),
             ( "/Settings/sep1", None, None, 0, "<Separator>" ),
             ( "/Settings/Left-to-Right", None, self.do_direction_changed, gtk.TEXT_DIR_LTR, "<RadioItem>" ),
             ( "/Settings/Right-to-Left", None, self.do_direction_changed, gtk.TEXT_DIR_RTL, "/Settings/Left-to-Right" ),
             ( "/Settings/sep1", None, None, 0, "<Separator>" ),
-            ( "/Settings/Sane spacing", None, self.do_spacing_changed, gtk.FALSE, "<RadioItem>" ),
-            ( "/Settings/Funky spacing", None, self.do_spacing_changed, gtk.TRUE, "/Settings/Sane spacing" ),
+            ( "/Settings/Sane spacing", None, self.do_spacing_changed, False, "<RadioItem>" ),
+            ( "/Settings/Funky spacing", None, self.do_spacing_changed, True, "/Settings/Sane spacing" ),
             ( "/Settings/sep1", None, None, 0, "<Separator>" ),
-            ( "/Settings/Don't cycle color tags", None, self.do_color_cycle_changed, gtk.FALSE, "<RadioItem>" ),
-            ( "/Settings/Cycle colors", None, self.do_color_cycle_changed, gtk.TRUE, "/Settings/Don't cycle color tags" ),
+            ( "/Settings/Don't cycle color tags", None, self.do_color_cycle_changed, False, "<RadioItem>" ),
+            ( "/Settings/Cycle colors", None, self.do_color_cycle_changed, True, "/Settings/Don't cycle color tags" ),
             ( "/_Attributes", None, None, 0, "<Branch>" ),
-            ( "/Attributes/Editable", None, self.do_apply_editable, gtk.TRUE, None ),
-            ( "/Attributes/Not editable", None, self.do_apply_editable, gtk.FALSE, None ),
-            ( "/Attributes/Invisible", None, self.do_apply_invisible, gtk.FALSE, None ),
-            ( "/Attributes/Visible", None, self.do_apply_invisible, gtk.TRUE, None ),
-            ( "/Attributes/Custom tabs", None, self.do_apply_tabs, gtk.FALSE, None ),
-            ( "/Attributes/Default tabs", None, self.do_apply_tabs, gtk.TRUE, None ),
-            ( "/Attributes/Color cycles", None, self.do_apply_colors, gtk.TRUE, None ),
-            ( "/Attributes/No colors", None, self.do_apply_colors, gtk.FALSE, None ),
+            ( "/Attributes/Editable", None, self.do_apply_editable, True, None ),
+            ( "/Attributes/Not editable", None, self.do_apply_editable, False, None ),
+            ( "/Attributes/Invisible", None, self.do_apply_invisible, False, None ),
+            ( "/Attributes/Visible", None, self.do_apply_invisible, True, None ),
+            ( "/Attributes/Custom tabs", None, self.do_apply_tabs, False, None ),
+            ( "/Attributes/Default tabs", None, self.do_apply_tabs, True, None ),
+            ( "/Attributes/Color cycles", None, self.do_apply_colors, True, None ),
+            ( "/Attributes/No colors", None, self.do_apply_colors, False, None ),
             ( "/Attributes/Remove all tags", None, self.do_remove_tags, 0, None ),
             ( "/Attributes/Properties", None, self.do_properties, 0, None ),
             ( "/_Test", None, None, 0, "<Branch>" ),
@@ -570,11 +570,11 @@ class View(gtk.Window):
 
         self.add_accel_group(self.accel_group)
 
-        vbox = gtk.VBox(gtk.FALSE, 0)
+        vbox = gtk.VBox(False, 0)
         self.add(vbox)
 
         vbox.pack_start(self.item_factory.get_widget("<main>"),
-                        gtk.FALSE, gtk.FALSE, 0)
+                        False, False, 0)
   
         sw = gtk.ScrolledWindow()
         sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -601,7 +601,7 @@ class View(gtk.Window):
 
         self.text_view.connect("expose_event", self.line_numbers_expose)
   
-        vbox.pack_start(sw, gtk.TRUE, gtk.TRUE, 0)
+        vbox.pack_start(sw, True, True, 0)
         sw.add(self.text_view)
 
         self.set_default_size(500, 500)
@@ -617,7 +617,7 @@ class View(gtk.Window):
         TestText.active_window_stack.push(self)
         self.check_close_view()
         TestText.active_window_stack.pop()
-        return gtk.TRUE
+        return True
     #
     # Menu callbacks
     #
@@ -648,11 +648,11 @@ class View(gtk.Window):
         if not buffer.fill_file_buffer(filename):
             if new_view != self:
                 new_view.close_view()
-            return gtk.FALSE
+            return False
         else:
             buffer.filename = filename
             buffer.filename_set()
-            return gtk.TRUE;
+            return True;
 
     def do_open(self, callback_action, widget):
         FileSel().run(self, "Open File", None, self.open_ok_func)
@@ -696,7 +696,7 @@ class View(gtk.Window):
         buffer = self.text_view.get_buffer()
 
         start, end = buffer.get_bounds()
-        mark = buffer.create_mark(None, end, gtk.FALSE)
+        mark = buffer.create_mark(None, end, False)
 
         buffer.insert(end,
                       "Hello this is multiple lines of text\n"
@@ -704,7 +704,7 @@ class View(gtk.Window):
                       "Line 3\n"  "Line 4\n"
                       "Line 5\n")
 
-        self.text_view.scroll_to_mark(mark, 0, gtk.TRUE, 0.0, 1.0)
+        self.text_view.scroll_to_mark(mark, 0, True, 0.0, 1.0)
         buffer.delete_mark(mark)
 
     def do_wrap_changed(self, callback_action, widget):
@@ -823,7 +823,7 @@ class View(gtk.Window):
                             ("Forward", RESPONSE_FORWARD,
                              "Backward", RESPONSE_BACKWARD,
                              gtk.STOCK_CANCEL, gtk.RESPONSE_NONE))
-        dialog.vbox.pack_end(search_text, gtk.TRUE, gtk.TRUE, 0)
+        dialog.vbox.pack_end(search_text, True, True, 0)
         dialog.buffer = search_text.get_buffer()
         dialog.connect("response", self.dialog_response_callback)
 
@@ -851,7 +851,7 @@ class View(gtk.Window):
                 info['click_y'] = child.allocation.y + event.y
         elif event.type == gtk.gdk.BUTTON_RELEASE:
             if info['button'] < 0:
-                return gtk.FALSE
+                return False
 
             if info['button'] == event.button:
                 info['button'] = -1;
@@ -863,7 +863,7 @@ class View(gtk.Window):
                 text_view.move_child(child, x, y)
         elif gtk.gdk.MOTION_NOTIFY:
             if info['button'] < 0:
-                return gtk.FALSE
+                return False
             x, y = child.get_pointer() # ensure more events
             # to window coords from event box coords
             x += child.allocation.x
@@ -872,7 +872,7 @@ class View(gtk.Window):
             y = info['start_y'] + (y - info['click_y'])
             text_view.move_child(child, x, y)
 
-        return gtk.FALSE
+        return False
 
     def add_movable_child(self, text_view, window):
         label = gtk.Label("Drag me around")  
@@ -1006,12 +1006,12 @@ class View(gtk.Window):
         text_view = self.text_view
         if mark == buffer.get_insert():
             tab_window = text_view.get_window(gtk.TEXT_WINDOW_TOP)
-            tab_window.invalidate_rect(None, gtk.FALSE)
-            #tab_window.invalidate_rect(tab_window.get_geometry()[:4], gtk.FALSE)
+            tab_window.invalidate_rect(None, False)
+            #tab_window.invalidate_rect(tab_window.get_geometry()[:4], False)
       
             tab_window = text_view.get_window(gtk.TEXT_WINDOW_BOTTOM)
-            tab_window.invalidate_rect(None, gtk.FALSE)
-            #tab_window.invalidate_rect(tab_window.get_geometry()[:4], gtk.FALSE)
+            tab_window.invalidate_rect(None, False)
+            #tab_window.invalidate_rect(tab_window.get_geometry()[:4], False)
 
     def tab_stops_expose(self, widget, event):
         #print self, widget, event
@@ -1028,7 +1028,7 @@ class View(gtk.Window):
             type = gtk.TEXT_WINDOW_BOTTOM
             target = bottom_win
         else:
-            return gtk.FALSE
+            return False
 
         first_x = event.area.x
         last_x = first_x + event.area.width
@@ -1042,7 +1042,7 @@ class View(gtk.Window):
         insert.get_attributes(attrs)
 
         tabslist = []
-        in_pixels = gtk.FALSE
+        in_pixels = False
         if attrs.tabs:
             tabslist = attrs.tabs.get_tabs()
             in_pixels = attrs.tabs.get_positions_in_pixels()
@@ -1055,7 +1055,7 @@ class View(gtk.Window):
             target.draw_line(text_view.style.fg_gc[text_view.state],
                              pos, 0, pos, 15)
 
-        return gtk.TRUE
+        return True
 
     def get_lines(self, first_y, last_y, buffer_coords, numbers):
         text_view = self.text_view
@@ -1093,7 +1093,7 @@ class View(gtk.Window):
             type = gtk.TEXT_WINDOW_RIGHT
             target = right_win
         else:
-            return gtk.FALSE
+            return False
   
         first_y = event.area.y
         last_y = first_y + event.area.height
@@ -1112,11 +1112,11 @@ class View(gtk.Window):
             x, pos = text_view.buffer_to_window_coords(type, 0, pixels[i])
             str = "%d" % numbers[i]
             layout.set_text(str)
-            widget.style.paint_layout(target, widget.state, gtk.FALSE,
+            widget.style.paint_layout(target, widget.state, False,
                                       None, widget, None, 2, pos + 2, layout)
 
         # don't stop emission, need to draw children
-        return gtk.FALSE
+        return False
 
     def add_example_widgets(self):
         buffer = self.text_view.get_buffer()
